@@ -51,8 +51,8 @@ gboolean gexiv2_metadata_has_xmp_tag(GExiv2Metadata *self, const gchar* tag) {
     Exiv2::XmpData &xmp_data = self->priv->image->xmpData();
     
     for (Exiv2::XmpData::iterator it = xmp_data.begin(); it != xmp_data.end(); ++it) {
-        if (g_ascii_strcasecmp(tag, it->key().c_str()) == 0)
-            return true;
+        if (it->count() > 0 && g_ascii_strcasecmp(tag, it->key().c_str()) == 0)
+            return TRUE;
     }
     
     return FALSE;
@@ -69,9 +69,9 @@ gboolean gexiv2_metadata_clear_xmp_tag(GExiv2Metadata *self, const gchar* tag) {
     
     Exiv2::XmpData::iterator it = xmp_data.begin();
     while (it != xmp_data.end()) {
-        if (g_ascii_strcasecmp(tag, it->key().c_str()) == 0) {
+        if (it->count() > 0 && g_ascii_strcasecmp(tag, it->key().c_str()) == 0) {
             it = xmp_data.erase(it);
-            erased = true;
+            erased = TRUE;
         } else {
             it++;
         }
@@ -94,8 +94,10 @@ gchar** gexiv2_metadata_get_xmp_tags (GExiv2Metadata *self) {
     gint count = 0;
     
     for (Exiv2::XmpData::iterator it = xmp_data.begin(); it != xmp_data.end(); ++it) {
-        list = g_slist_prepend (list, g_strdup (it->key ().c_str ()));
-        count = count + 1;
+        if (it->count() > 0) {
+            list = g_slist_prepend (list, g_strdup (it->key ().c_str ()));
+            count++;
+        }
     }
     
     data = g_new (gchar*, count + 1);
@@ -116,10 +118,11 @@ gchar* gexiv2_metadata_get_xmp_tag_string (GExiv2Metadata *self, const gchar* ta
     Exiv2::XmpData& xmp_data = self->priv->image->xmpData();
     
     try {
-        
         Exiv2::XmpData::iterator it = xmp_data.findKey(Exiv2::XmpKey(tag));
+        while (it != xmp_data.end() && it->count() == 0)
+            it++;
         
-        if (it != xmp_data.end ())
+        if (it != xmp_data.end())
             return g_strdup (it->toString ().c_str ());
     } catch (Exiv2::Error& e) {
         LOG_ERROR(e);
@@ -137,7 +140,10 @@ gchar* gexiv2_metadata_get_xmp_tag_interpreted_string (GExiv2Metadata *self, con
     
     try {
         Exiv2::XmpData::iterator it = xmp_data.findKey(Exiv2::XmpKey(tag));
-        if (it != xmp_data.end ()) {
+        while (it != xmp_data.end() && it->count() == 0)
+            it++;
+        
+        if (it != xmp_data.end()) {
             std::ostringstream os;
             it->write (os);
             
@@ -160,7 +166,7 @@ gboolean gexiv2_metadata_set_xmp_tag_string (GExiv2Metadata *self, const gchar*
     try {
         self->priv->image->xmpData()[tag] = value;
         
-        return true;
+        return TRUE;
     } catch (Exiv2::Error& e) {
         LOG_ERROR(e);
     }
@@ -177,7 +183,10 @@ glong gexiv2_metadata_get_xmp_tag_long (GExiv2Metadata *self, const gchar* tag)
     
     try {
         Exiv2::XmpData::iterator it = xmp_data.findKey(Exiv2::XmpKey(tag));
-        if (it != xmp_data.end ())
+        while (it != xmp_data.end() && it->count() == 0)
+            it++;
+        
+        if (it != xmp_data.end())
             return it->toLong ();
     } catch (Exiv2::Error& e) {
         LOG_ERROR(e);
@@ -194,7 +203,7 @@ gboolean gexiv2_metadata_set_xmp_tag_long (GExiv2Metadata *self, const gchar* ta
     try {
         self->priv->image->xmpData()[tag] = value;
         
-        return true;
+        return TRUE;
     } catch (Exiv2::Error& e) {
         LOG_ERROR(e);
     }
@@ -211,7 +220,10 @@ gchar** gexiv2_metadata_get_xmp_tag_multiple (GExiv2Metadata *self, const gchar*
     
     try {
         Exiv2::XmpData::iterator it = xmp_data.findKey(Exiv2::XmpKey(tag));
-        if (it != xmp_data.end ()) {
+        while (it != xmp_data.end() && it->count() == 0)
+            it++;
+        
+        if (it != xmp_data.end()) {
             int size = it->count ();
             gchar **array = g_new (gchar*, size + 1);
             array[size] = NULL;
@@ -242,9 +254,12 @@ gboolean gexiv2_metadata_set_xmp_tag_multiple (GExiv2Metadata *self, const gchar
     
     try {
         /* first clear existing tag */
-        Exiv2::XmpData::iterator xmp_it = xmp_data.findKey(Exiv2::XmpKey(tag));
-        if (xmp_it != xmp_data.end ())
-            xmp_data.erase (xmp_it);
+        Exiv2::XmpData::iterator it = xmp_data.findKey(Exiv2::XmpKey(tag));
+        while (it != xmp_data.end() && it->count() == 0)
+            it++;
+        
+        if (it != xmp_data.end())
+            xmp_data.erase (it);
         
         /* ... and then set the others */
         const gchar **val_it = values;
@@ -253,7 +268,7 @@ gboolean gexiv2_metadata_set_xmp_tag_multiple (GExiv2Metadata *self, const gchar
             ++val_it;
         }
         
-        return true;
+        return TRUE;
     } catch (Exiv2::Error& e) {
         LOG_ERROR(e);
     }
@@ -285,4 +300,43 @@ const gchar* gexiv2_metadata_get_xmp_tag_description (const gchar* tag) {
     return NULL;
 }
 
+gboolean gexiv2_metadata_register_xmp_namespace (const gchar* name, const gchar* prefix) {
+    g_return_val_if_fail(name != NULL, FALSE);
+    g_return_val_if_fail(prefix != NULL, FALSE);
+
+    try {
+        Exiv2::XmpProperties::ns(prefix);
+    } catch (Exiv2::Error& error) {
+        // No namespace, OK to register
+        Exiv2::XmpProperties::registerNs(name, prefix);
+        return TRUE;
+    }
+
+    return FALSE;
+}
+
+gboolean gexiv2_metadata_unregister_xmp_namespace (const gchar* name) {
+    g_return_val_if_fail(name != NULL, FALSE);
+
+    std::string prefix = Exiv2::XmpProperties::prefix(name);
+
+    if (!prefix.empty()) {
+        // Unregister
+        Exiv2::XmpProperties::unregisterNs(name);
+
+        try {
+            Exiv2::XmpProperties::ns(prefix);
+        } catch (Exiv2::Error& error) {
+            // Namespace successfully removed
+            return TRUE;
+        }
+    }
+
+    return FALSE;
+}
+
+void gexiv2_metadata_unregister_all_xmp_namespaces (void) {
+    Exiv2::XmpProperties::unregisterNs();
+}
+
 G_END_DECLS
